==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/pt_BR.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartilhamento de servidor para servidor não está habilitado no servidor",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém caracteres inválidos.",
    "Not allowed to create a federated share with the same user server" : "Não permitido para criar um compartilhamento associado com o mesmo servidor do usuário",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticação com o compartilhamento remoto, a senha deve estar errada",
    "Storage not valid" : "Armazenamento não válido",
    "Couldn't add remote share" : "Não foi possível adicionar compartilhamento remoto",
    "Shared with you" : "Compartilhado com você",
    "Shared with others" : "Compartilhado com outros",
    "Shared by link" : "Compartilhado por link",
    "Anonymous upload" : "Envio anônimo",
    "Click to select files or use drag & drop to upload" : "Clique para selecionar os arquivos ou use o recurso arrastar & soltar para fazer o envio",
    "Uploaded files" : "Arquivos enviados",
    "Uploading..." : "Enviando...",
    "Nothing shared with you yet" : "Nada compartilhado com você até agora",
    "Files and folders others share with you will show up here" : "Arquivos e pastas que outros compartilham com você são mostrados aqui",
    "Nothing shared yet" : "Nada compartilhado até agora",
    "Files and folders you share will show up here" : "Arquivos e pastas que você compartilha são mostrados aqui",
    "No shared links" : "Nenhum link compartilhado",
    "Files and folders you share by link will show up here" : "Arquivos e pastas que você compartilha com link são mostrados aqui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Você quer adicionar o compartilhamento remoto {name} de {owner}@{remote}?",
    "Remote share" : "Compartilhamento remoto",
    "Remote share password" : "Senha do compartilhamento remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar compartilhamento remoto",
    "You can upload into this folder" : "Você não pode enviar arquivos para esta pasta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nenhuma instalação ownCloud (7 ou superior) foi encontrada em {remote}",
    "Invalid ownCloud url" : "Url invalida para ownCloud",
    "Share" : "Compartilhar",
    "No expiration date set" : "Nenhuma data de expiração foi configurada",
    "Shared by" : "Compartilhado por",
    "Sharing" : "Compartilhamento",
    "Share API is disabled" : "O compartilhamento de API está desabilitado.",
    "Wrong share ID, share doesn't exist" : "ID de compartilhamento errado, o compartilhamento não existe",
    "Could not delete share" : "Não foi possível eliminar o compartilhamento",
    "Please specify a file or folder path" : "Por favor especifique um arquivo ou caminho",
    "Wrong path, file/folder doesn't exist" : "Caminho errado, arquivo/pasta não existe",
    "Cannot remove all permissions" : "Não é possível remover todas as permissões",
    "Please specify a valid user" : "Por favor especifique um usuário válido",
    "Group sharing is disabled by the administrator" : "Grupo de compartilhamento foi desabilitado pelo administrador",
    "Please specify a valid group" : "Por favor especifique um grupo válido",
    "Public link sharing is disabled by the administrator" : "Link de compartilhamento público foi desativado pelo administrador",
    "Public upload disabled by the administrator" : "Envio público foi desativado pelo administrador",
    "Public upload is only possible for publicly shared folders" : "Envio pública só é possível para pastas compartilhadas publicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato de data deve ser YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "O compartilhando %s falhou porque o backend não permite ações de tipo %s",
    "Unknown share type" : "Tipo de compartilhamento desconhecido",
    "Not a directory" : "Não é um diretório",
    "Could not lock path" : "Não foi possível bloquear o caminho",
    "Can't change permissions for public share links" : "Não é possível alterar permissões para compartilhar links públicos",
    "Wrong or no update parameter given" : "Está errado ou nenhum parâmetro de atualização foi fornecido",
    "Cannot increase permissions" : "Não pode haver aumento de permissões",
    "A file or folder has been <strong>shared</strong>" : "Um arquivo ou pasta foi <strong>compartilhado</strong> ",
    "A file or folder was shared from <strong>another server</strong>" : "Um arquivo ou pasta foi compartilhado a partir de <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Um arquivo ou pasta compartilhado publicamente foi <strong>baixado</strong>",
    "You received a new remote share %2$s from %1$s" : "Você recebeu um novo conpartilhamento remoto %2$s de %1$s",
    "You received a new remote share from %s" : "Você recebeu um novo compartilhamento remoto de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceitou o compartilhamento remoto %2$s",
    "%1$s declined remote share %2$s" : "%1$s declinou o compartilhamento remoto %2$s",
    "%1$s unshared %2$s from you" : "%1$s não compartilhados %2$s de você",
    "Public shared folder %1$s was downloaded" : "A pasta %1$s compartilhada publicamente foi baixada",
    "Public shared file %1$s was downloaded" : "O arquivo %1$s compartilhado publicamente foi baixado",
    "You shared %1$s with %2$s" : "Você compartilhou %1$s com %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartilhado %1$s com %3$s",
    "You removed the share of %2$s for %1$s" : "Você removeu o compartilhamento de %2$s para %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s removido o compartilhamento de %3$s para %1$s",
    "You shared %1$s with group %2$s" : "Você compartilhou %1$s com o grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartilhado %1$s com o grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Você removeu o compartilhamento de %2$s para %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s removido o compartilhamento do grupo %3$s para %1$s",
    "%2$s shared %1$s via link" : "%2$s compartilhado via link %1$s",
    "You shared %1$s via link" : "Você compartilhou %1$s via link",
    "You removed the public link for %1$s" : "Você removeu o link público de %1$s",
    "%2$s removed the public link for %1$s" : "%2$s removeu o link público de %1$s",
    "Your public link for %1$s expired" : "O seu link público para %1$s expirou",
    "The public link of %2$s for %1$s expired" : "O link público de %2$s para %1$s expirou",
    "%2$s shared %1$s with you" : "%2$s compartilhou %1$s com você",
    "%2$s removed the share for %1$s" : "%2$s removeu o compartilhamento para %1$s",
    "Downloaded via public link" : "Baixar via link público",
    "Shared with %2$s" : "Compartilhado com %2$s",
    "Shared with %3$s by %2$s" : "Compartilhado com %3$s por %2$s",
    "Removed share for %2$s" : "Removido compartilhamento para %2$s",
    "%2$s removed share for %3$s" : "%2$s removeu o compartilhamento para %3$s",
    "Shared with group %2$s" : "Compartilhado com o grupo %2$s",
    "Shared with group %3$s by %2$s" : "Compartilhado com o grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Removido compartilhamento para o grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s removido compartilhamento do grupo %3$s",
    "Shared via link by %2$s" : "Compartilhado via link por %2$s",
    "Shared via public link" : "Compartilhado via link público",
    "Removed public link" : "Removido o link público",
    "%2$s removed public link" : "%2$s removeu o link público",
    "Public link expired" : "O link público expirou",
    "Public link of %2$s expired" : "O link público de %2$s expirou",
    "Shared by %2$s" : "Compartilhado por %2$s",
    "Shares" : "Compartilhamentos",
    "This share is password-protected" : "Este compartilhamento esta protegido por senha",
    "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
    "Password" : "Senha",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Name" : "Nome",
    "Share time" : "Data compartilhado",
    "Expiration date" : "Data de expiração",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, este link parece não mais  funcionar.",
    "Reasons might be:" : "As razões podem ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "o link expirou",
    "sharing is disabled" : "o compartilhamento está desativado",
    "For more info, please ask the person who sent this link." : "Para mais informações, por favor, pergunte a pessoa que enviou este link.",
    "%s is publicly shared" : "%s foi compartilhado publicamente",
    "Add to your ownCloud" : "Adiconar ao seu ownCloud",
    "Download" : "Baixar",
    "Download %s" : "Baixar %s",
    "Direct link" : "Link direto",
    "No permission to create share" : "Sem permissão para criar compartilhamento",
    "Pending" : "Pendente",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Declined" : "Rejeitado",
    "An error occurred while updating share state: {message}" : "Ocorreu um erro ao atualizar o estado de compartilhamento: {message}",
    "Accept Share" : "Aceitar Compartilhamento",
    "Decline Share" : "Recusar Compartilhamento",
    "Only recipient can change accepted state" : "Apenas o destinatário pode alterar o estado de aceito",
    "File sharing" : "Compartilhamento de arquivo",
    "State" : "Estado",
    "The group is blacklisted for sharing" : "O grupo está na lista negra para compartilhamento",
    "Files Sharing" : "Compartilhamento de Arquivos",
    "Exclude groups from receiving shares." : "Excluir grupos de receber compartilhamentos.",
    "These groups will not receive shares. Members of the group can still send and receive shares outside of the group." : "Esses grupos não receberão compartilhamentos. Os membros do grupo ainda podem enviar e receber compartilhamentos fora do grupo.",
    "Public link" : "Linque público",
    "Couldn't send mail to following recipient(s): %s " : "Não foi possível enviar email para o(s) seguinte(s) destinatário(s): %s ",
    "Group Sharing Blacklist" : "Lista negra de Compartilhamento de Grupos",
    "Exclude groups from receiving shares" : "Excluir grupos de receber compartilhamentos",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Esses grupos não estarão disponíveis para compartilhar. Os membros do grupo não estão restritos a iniciar ações e podem receber ações de outros grupos dos quais são membros, como de costume."
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/pt_BR.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartilhamento de servidor para servidor não está habilitado no servidor",
    "The mountpoint name contains invalid characters." : "O nome do ponto de montagem contém caracteres inválidos.",
    "Not allowed to create a federated share with the same user server" : "Não permitido para criar um compartilhamento associado com o mesmo servidor do usuário",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido ou não confiável",
    "Could not authenticate to remote share, password might be wrong" : "Não foi possível autenticação com o compartilhamento remoto, a senha deve estar errada",
    "Storage not valid" : "Armazenamento não válido",
    "Couldn't add remote share" : "Não foi possível adicionar compartilhamento remoto",
    "Shared with you" : "Compartilhado com você",
    "Shared with others" : "Compartilhado com outros",
    "Shared by link" : "Compartilhado por link",
    "Anonymous upload" : "Envio anônimo",
    "Click to select files or use drag & drop to upload" : "Clique para selecionar os arquivos ou use o recurso arrastar & soltar para fazer o envio",
    "Uploaded files" : "Arquivos enviados",
    "Uploading..." : "Enviando...",
    "Nothing shared with you yet" : "Nada compartilhado com você até agora",
    "Files and folders others share with you will show up here" : "Arquivos e pastas que outros compartilham com você são mostrados aqui",
    "Nothing shared yet" : "Nada compartilhado até agora",
    "Files and folders you share will show up here" : "Arquivos e pastas que você compartilha são mostrados aqui",
    "No shared links" : "Nenhum link compartilhado",
    "Files and folders you share by link will show up here" : "Arquivos e pastas que você compartilha com link são mostrados aqui",
    "An error occurred while updating share state: {message}" : "Ocorreu um erro ao atualizar o estado de compartilhamento: {message}",
    "Accept Share" : "Aceitar Compartilhamento",
    "Decline Share" : "Recusar Compartilhamento",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Você quer adicionar o compartilhamento remoto {name} de {owner}@{remote}?",
    "Remote share" : "Compartilhamento remoto",
    "Remote share password" : "Senha do compartilhamento remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Adicionar compartilhamento remoto",
    "You can upload into this folder" : "Você não pode enviar arquivos para esta pasta",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nenhuma instalação ownCloud (7 ou superior) foi encontrada em {remote}",
    "Invalid ownCloud url" : "Url invalida para ownCloud",
    "Share" : "Compartilhar",
    "No expiration date set" : "Nenhuma data de expiração foi configurada",
    "Declined" : "Rejeitado",
    "Pending" : "Pendente",
    "Shared by" : "Compartilhado por",
    "Sharing" : "Compartilhamento",
    "A file or folder has been <strong>shared</strong>" : "Um arquivo ou pasta foi <strong>compartilhado</strong> ",
    "A file or folder was shared from <strong>another server</strong>" : "Um arquivo ou pasta foi compartilhado a partir de <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Um arquivo ou pasta compartilhado publicamente foi <strong>baixado</strong>",
    "You received a new remote share %2$s from %1$s" : "Você recebeu um novo conpartilhamento remoto %2$s de %1$s",
    "You received a new remote share from %s" : "Você recebeu um novo compartilhamento remoto de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceitou o compartilhamento remoto %2$s",
    "%1$s declined remote share %2$s" : "%1$s declinou o compartilhamento remoto %2$s",
    "%1$s unshared %2$s from you" : "%1$s não compartilhados %2$s de você",
    "Public shared folder %1$s was downloaded" : "A pasta %1$s compartilhada publicamente foi baixada",
    "Public shared file %1$s was downloaded" : "O arquivo %1$s compartilhado publicamente foi baixado",
    "You shared %1$s with %2$s" : "Você compartilhou %1$s com %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartilhado %1$s com %3$s",
    "You removed the share of %2$s for %1$s" : "Você removeu o compartilhamento de %2$s para %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s removido o compartilhamento de %3$s para %1$s",
    "You unshared %1$s shared by %2$s from self" : "Você descompartilhou %1$s compartilhado por %2$s de si mesmo",
    "You shared %1$s with group %2$s" : "Você compartilhou %1$s com o grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartilhado %1$s com o grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Você removeu o compartilhamento de %2$s para %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s removido o compartilhamento do grupo %3$s para %1$s",
    "%2$s shared %1$s via link" : "%2$s compartilhado via link %1$s",
    "You shared %1$s via link" : "Você compartilhou %1$s via link",
    "You removed the public link for %1$s" : "Você removeu o link público de %1$s",
    "%2$s removed the public link for %1$s" : "%2$s removeu o link público de %1$s",
    "Your public link for %1$s expired" : "O seu link público para %1$s expirou",
    "The public link of %2$s for %1$s expired" : "O link público de %2$s para %1$s expirou",
    "%2$s shared %1$s with you" : "%2$s compartilhou %1$s com você",
    "%2$s removed the share for %1$s" : "%2$s removeu o compartilhamento para %1$s",
    "Downloaded via public link" : "Baixar via link público",
    "Shared with %2$s" : "Compartilhado com %2$s",
    "Shared with %3$s by %2$s" : "Compartilhado com %3$s por %2$s",
    "Removed share for %2$s" : "Removido compartilhamento para %2$s",
    "%2$s removed share for %3$s" : "%2$s removeu o compartilhamento para %3$s",
    "Unshared %1$s from self" : "Descompartilhou %1$s de sí mesmo",
    "Shared with group %2$s" : "Compartilhado com o grupo %2$s",
    "Shared with group %3$s by %2$s" : "Compartilhado com o grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Removido compartilhamento para o grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s removido compartilhamento do grupo %3$s",
    "Shared via link by %2$s" : "Compartilhado via link por %2$s",
    "Shared via public link" : "Compartilhado via link público",
    "Removed public link" : "Removido o link público",
    "%2$s removed public link" : "%2$s removeu o link público",
    "Public link expired" : "O link público expirou",
    "Public link of %2$s expired" : "O link público de %2$s expirou",
    "Shared by %2$s" : "Compartilhado por %2$s",
    "Shares" : "Compartilhamentos",
    "File sharing" : "Compartilhamento de arquivo",
    "Public link" : "Linque público",
    "Couldn't send mail to following recipient(s): %s " : "Não foi possível enviar email para o(s) seguinte(s) destinatário(s): %s ",
    "Share API is disabled" : "O compartilhamento de API está desabilitado.",
    "Wrong share ID, share doesn't exist" : "ID de compartilhamento errado, o compartilhamento não existe",
    "Could not delete share" : "Não foi possível eliminar o compartilhamento",
    "Please specify a file or folder path" : "Por favor especifique um arquivo ou caminho",
    "Wrong path, file/folder doesn't exist" : "Caminho errado, arquivo/pasta não existe",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato de data deve ser YYYY-MM-DD",
    "Please specify a valid user" : "Por favor especifique um usuário válido",
    "Group sharing is disabled by the administrator" : "Grupo de compartilhamento foi desabilitado pelo administrador",
    "Please specify a valid group" : "Por favor especifique um grupo válido",
    "The group is blacklisted for sharing" : "O grupo está na lista negra para compartilhamento",
    "Public link sharing is disabled by the administrator" : "Link de compartilhamento público foi desativado pelo administrador",
    "Public upload disabled by the administrator" : "Envio público foi desativado pelo administrador",
    "Public upload is only possible for publicly shared folders" : "Envio pública só é possível para pastas compartilhadas publicamente",
    "Sharing %s failed because the back end does not allow shares from type %s" : "O compartilhando %s falhou porque o backend não permite ações de tipo %s",
    "Unknown share type" : "Tipo de compartilhamento desconhecido",
    "Not a directory" : "Não é um diretório",
    "Could not lock path" : "Não foi possível bloquear o caminho",
    "Could not update share" : "Não foi possível atualizar compartilhamento",
    "Can't change permissions for public share links" : "Não é possível alterar permissões para compartilhar links públicos",
    "Only recipient can change accepted state" : "Apenas o destinatário pode alterar o estado de aceito",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" compartilhado \"%3$s\" com você (em nome de \"%2$s\")",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" compartilhado \"%3$s\" com você",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\"convidou você para ver \"%3$s\" (em nome de \"%2$s\")",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" convidou você para visualizar \"%3$s\"",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "Automatically accept new incoming local user shares" : "Aceitar automaticamente novos compartilhamentos recebidos de usuários locais",
    "This share is password-protected" : "Este compartilhamento esta protegido por senha",
    "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
    "Password" : "Senha",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Name" : "Nome",
    "State" : "Estado",
    "Share time" : "Data compartilhado",
    "Expiration date" : "Data de expiração",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, este link parece não mais  funcionar.",
    "Reasons might be:" : "As razões podem ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "o link expirou",
    "sharing is disabled" : "o compartilhamento está desativado",
    "For more info, please ask the person who sent this link." : "Para mais informações, por favor, pergunte a pessoa que enviou este link.",
    "%s is publicly shared" : "%s foi compartilhado publicamente",
    "Download" : "Baixar",
    "Download %s" : "Baixar %s",
    "Direct link" : "Link direto",
    "Nothing to configure." : "Nada para configurar.",
    "Group Sharing Blacklist" : "Lista negra de Compartilhamento de Grupos",
    "Exclude groups from receiving shares" : "Excluir grupos de receber compartilhamentos",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Esses grupos não estarão disponíveis para compartilhar. Os membros do grupo não estão restritos a iniciar ações e podem receber ações de outros grupos dos quais são membros, como de costume."
},
"nplurals=2; plural=(n > 1);");
